@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild::File;
 use strict;
 use warnings;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 $VERSION = eval $VERSION;
 
 sub new {
@@ -23,7 +23,7 @@ sub has_version {
 sub get {
   my $self = shift;
   my $filename = $self->filename;
-  $self->repository->get_file($filename);
+  $filename = $self->repository->get_file($filename);
   return $filename;
 }
 
